'use strict';

var _require = require('./http'),
    httpGet = _require.httpGet,
    httpDelete = _require.httpDelete,
    httpPost = _require.httpPost,
    httpPut = _require.httpPut;

var _require2 = require('assert'),
    deepEqual = _require2.deepEqual;

var defaultHeaders = {
  'Content-Type': 'application/json;charset=UTF-8'
};

describe('cmds', function () {
  describe('httpGet', function () {
    it('should return an httpGet object', function () {
      var actual = httpGet('http://www.example.com');
      var expected = {
        type: 'httpGet',
        url: 'http://www.example.com',
        headers: {},
        options: {}
      };
      deepEqual(actual, expected);
    });

    it('should return an httpGet', function () {
      var actual = httpGet('http://www.example.com', {
        'Content-Type': 'application/json'
      }, {
        credentials: 'include'
      });

      var expected = {
        type: 'httpGet',
        url: 'http://www.example.com',
        headers: {
          'Content-Type': 'application/json'
        },
        options: {
          credentials: 'include'
        }
      };

      deepEqual(actual, expected);
    });
  });

  describe('httpDelete', function () {
    it('should return an httpDelete object', function () {
      var actual = httpDelete('http://www.example.com');
      var expected = {
        type: 'httpDelete',
        url: 'http://www.example.com',
        headers: {},
        options: {}
      };
      deepEqual(actual, expected);
    });

    it('should return an httpDelete', function () {
      var actual = httpDelete('http://www.example.com', {
        'Content-Type': 'application/json'
      }, {
        credentials: 'include'
      });

      var expected = {
        type: 'httpDelete',
        url: 'http://www.example.com',
        headers: {
          'Content-Type': 'application/json'
        },
        options: {
          credentials: 'include'
        }
      };

      deepEqual(actual, expected);
    });
  });

  describe('httpPost', function () {
    it('should return an httpPost object', function () {
      var actual = httpPost('http://www.example.com', { foo: 'bar' });
      var expected = {
        type: 'httpPost',
        url: 'http://www.example.com',
        payload: { foo: 'bar' },
        headers: defaultHeaders,
        options: {}
      };
      deepEqual(actual, expected);
    });

    it('should return an httpPost', function () {
      var actual = httpPost('http://www.example.com', { foo: 'bar' }, {
        'Content-Type': 'text/html'
      }, {
        credentials: 'include'
      });

      var expected = {
        type: 'httpPost',
        url: 'http://www.example.com',
        payload: { foo: 'bar' },
        headers: {
          'Content-Type': 'text/html'
        },
        options: {
          credentials: 'include'
        }
      };

      deepEqual(actual, expected);
    });
  });

  describe('httpPut', function () {
    it('should return an httpPut object', function () {
      var actual = httpPut('http://www.example.com', { foo: 'bar' });
      var expected = {
        type: 'httpPut',
        url: 'http://www.example.com',
        payload: { foo: 'bar' },
        headers: defaultHeaders,
        options: {}
      };
      deepEqual(actual, expected);
    });

    it('should return an httpPut', function () {
      var actual = httpPut('http://www.example.com', { foo: 'bar' }, {
        'Content-Type': 'text/html'
      }, {
        credentials: 'include'
      });

      var expected = {
        type: 'httpPut',
        url: 'http://www.example.com',
        payload: { foo: 'bar' },
        headers: {
          'Content-Type': 'text/html'
        },
        options: {
          credentials: 'include'
        }
      };

      deepEqual(actual, expected);
    });
  });
});
//# sourceMappingURL=http.spec.js.map