'use strict';

var _require = require('./hit'),
    hit = _require.hit;

var cmds = require('../cmds');

var _require2 = require('effects-as-data'),
    call = _require2.call;

test('hit()', function () {
  var handlers = {
    one: function one() {
      return 'foo';
    }
  };
  var testCmds = {
    one: { type: 'one' }
  };
  var cmd = cmds.hit(testCmds.one);
  return hit(cmd, { handlers: handlers, config: {}, call: call }).then(function (result) {
    expect(result).toEqual('foo');
  });
});

test('hit() should go to next on error', function () {
  var handlers = {
    one: function one() {
      throw new Error('oops');
    },
    two: function two() {
      return 'foo';
    }
  };
  var testCmds = {
    one: { type: 'one' },
    two: { type: 'two' }
  };
  var cmd = cmds.hit(testCmds.one, testCmds.two);
  return hit(cmd, { handlers: handlers, config: {}, call: call }).then(function (result) {
    expect(result).toEqual('foo');
  });
});

test('hit() should go to next on falsey value 1', function () {
  var handlers = {
    one: function one() {
      return null;
    },
    two: function two() {
      return 'foo';
    }
  };
  var testCmds = {
    one: { type: 'one' },
    two: { type: 'two' }
  };
  var cmd = cmds.hit(testCmds.one, testCmds.two);
  return hit(cmd, { handlers: handlers, config: {}, call: call }).then(function (result) {
    expect(result).toEqual('foo');
  });
});

test('hit() should go to next on falsey value 2', function () {
  var handlers = {
    one: function one() {
      return null;
    },
    two: function two() {
      return null;
    },
    three: function three() {
      return 'foo';
    }
  };
  var testCmds = {
    one: { type: 'one' },
    two: { type: 'two' },
    three: { type: 'three' }
  };
  var cmd = cmds.hit(testCmds.one, testCmds.two, testCmds.three);
  return hit(cmd, { handlers: handlers, config: {}, call: call }).then(function (result) {
    expect(result).toEqual('foo');
  });
});

test('hit() should throw error if no hits', async function () {
  var handlers = {
    one: function one() {
      return null;
    },
    two: function two() {
      return null;
    },
    three: function three() {
      return null;
    }
  };
  var testCmds = {
    one: { type: 'one' },
    two: { type: 'two' },
    three: { type: 'three' }
  };
  var cmd = cmds.hit(testCmds.one, testCmds.two, testCmds.three);
  try {
    await hit(cmd, { handlers: handlers, config: {}, call: call });
  } catch (e) {
    expect(e.message).toEqual('hit could not return a value because every cmd failed or returned a falsey value.');
    return;
  }
  fail('hit did not throw');
});

test('hit() should throw error if no hits and error', async function () {
  var handlers = {
    one: function one() {
      return null;
    },
    two: function two() {
      return null;
    },
    three: function three() {
      throw new Error('oops');
    }
  };
  var testCmds = {
    one: { type: 'one' },
    two: { type: 'two' },
    three: { type: 'three' }
  };
  var cmd = cmds.hit(testCmds.one, testCmds.two, testCmds.three);
  try {
    await hit(cmd, { handlers: handlers, config: {}, call: call });
  } catch (e) {
    expect(e.message).toEqual('hit could not return a value because every cmd failed or returned a falsey value.');
    return;
  }
  fail('hit did not throw');
});
//# sourceMappingURL=hit.spec.js.map