'use strict';

var fetch = require('fetch-everywhere');

var defaultHeaders = {
  'Content-Type': 'application/json;charset=UTF-8'
};

function httpGetFn(get, _ref) {
  var url = _ref.url,
      headers = _ref.headers,
      options = _ref.options;

  var defaultOptions = {
    method: 'GET',
    credentials: 'include'
  };
  var allOptions = Object.assign({}, defaultOptions, options, { headers: headers });
  return get(url, allOptions).then(checkStatus).then(parse(allOptions.meta));
}

function httpDeleteFn(remove, _ref2) {
  var url = _ref2.url,
      headers = _ref2.headers,
      options = _ref2.options;

  var defaultOptions = {
    method: 'DELETE',
    credentials: 'include'
  };
  var allOptions = Object.assign({}, defaultOptions, options, { headers: headers });
  return remove(url, allOptions).then(checkStatus).then(parse(allOptions.meta));
}

function httpPostFn(post, _ref3) {
  var url = _ref3.url,
      payload = _ref3.payload,
      headers = _ref3.headers,
      options = _ref3.options;

  var defaultOptions = {
    method: 'POST',
    credentials: 'include',
    body: JSON.stringify(payload),
    headers: defaultHeaders
  };
  var allOptions = Object.assign({}, defaultOptions, options, {
    headers: headers,
    body: JSON.stringify(payload)
  });
  return post(url, allOptions).then(checkStatus).then(parse(allOptions.meta));
}

function httpPutFn(put, _ref4) {
  var url = _ref4.url,
      payload = _ref4.payload,
      headers = _ref4.headers,
      options = _ref4.options;

  var defaultOptions = {
    method: 'PUT',
    credentials: 'include',
    body: JSON.stringify(payload),
    headers: defaultHeaders
  };
  var allOptions = Object.assign({}, defaultOptions, options, {
    headers: headers,
    body: JSON.stringify(payload)
  });
  return put(url, allOptions).then(checkStatus).then(parse(allOptions.meta));
}

function checkStatus(response) {
  if (response.status >= 200 && response.status < 300) {
    return response;
  } else {
    var error = new Error(response.statusText);
    return parse(true)(response).then(function (p) {
      error.payload = p.payload;
      error.meta = {
        status: response.status,
        statusText: response.statusText,
        headers: parseHeaders(response)
      };
      throw error;
    });
  }
}

var parse = function parse(includeMeta) {
  return function (r) {
    return r.text().then(function (text) {
      var payload = void 0;
      try {
        payload = JSON.parse(text);
      } catch (e) {
        payload = text;
      }

      if (includeMeta) {
        return {
          meta: {
            status: r.status,
            statusText: r.statusText,
            headers: parseHeaders(r)
          },
          payload: payload
        };
      } else {
        return payload;
      }
    });
  };
};

function parseHeaders(httpResponse) {
  var headersRaw = httpResponse.headers._headers || {};
  return Object.keys(headersRaw).reduce(function (p, c) {
    p[c] = headersRaw[c].join('');
    return p;
  }, {});
}

module.exports = {
  httpPostFn: httpPostFn,
  httpPost: function httpPost(payload) {
    return httpPostFn(fetch, payload);
  },
  httpPutFn: httpPutFn,
  httpPut: function httpPut(payload) {
    return httpPutFn(fetch, payload);
  },
  httpGetFn: httpGetFn,
  httpGet: function httpGet(payload) {
    return httpGetFn(fetch, payload);
  },
  httpDeleteFn: httpDeleteFn,
  httpDelete: function httpDelete(payload) {
    return httpDeleteFn(fetch, payload);
  }
};
//# sourceMappingURL=http.js.map